@@ -98,7 +98,7 @@ class Servico:
             return True
         if self.em_execucao():
             return False
-        if not self.executado():
+        if self.forcar_execucao():
             return True
         hoje, json = datetime.now(), response.json()[0]
         fim_execucao = {
